| animate_topo | R Documentation |
Display a topographic animation of the change in amplitude over time. The function enables direct rendering in Rstudio Viewer or saving the animation in gif format to the chosen location.
animate_topo(
data,
amplitude,
t_lim,
FS = 250,
t0 = 1,
mesh,
coords = NULL,
template = NULL,
col_range = NULL,
col_scale = NULL,
show_legend = TRUE,
contour = FALSE,
output_path = NULL,
...
)
data |
An input data frame or tibble with at least this required columns: |
amplitude |
A character specifying the name of the column from input data with EEG amplitude values. |
t_lim |
A numeric vector of length 2 with limits of time points (i.e., the length of the timeline displayed below the animation). |
FS |
The sampling frequency. Default value is 250 Hz. |
t0 |
Index of the zero time point, i.e. point, where 0 ms should be marked (most often time of the stimulus or time of the response). |
mesh |
A |
coords |
Sensor coordinates as a tibble or data frame with named |
template |
The kind of sensor template montage used. Currently the only available option is |
col_range |
A vector with minimum and maximum value of the amplitude used in the colour palette for plotting. If not defined, the range of interpolated signal is used. |
col_scale |
Optionally, a colour scale to be utilised for plotting. If not defined, it is computed from |
show_legend |
Logical. Indicates, whether legend should be displayed beside the graph. Default value is |
contour |
Logical. Indicates, whether contours should be plotted in the graph. Default value is |
output_path |
File path where the animation will be saved using |
... |
Additional parameters for animation according to gganimate::animate. |
For more details about required mesh structure see point_mesh function. If the input mesh structure does not match this format, an error or incorrect function behavior may occur.
The time part of input data is assumed to be in numbers of time points, conversion to ms takes place inside the function for drawing the timeline labels.
Due to the flexibility of the function (e.g. to mark and animate only a short section from the entire time course or to compare different data in the same time interval), it allows to enter and plot user-defined time ranges. If some values of the time are outside the t_lim range, the function writes a warning message - in that case the animation is still rendered, but the timeline will not match reality.
Note: When specifying the coords and template at the same time, the template parameter takes precedence and the coords parameter is ignored.
If output_path is NULL, the function prints the animation to the RStudio Viewer.
If output_path is specified, the animation is saved to the given file path and not displayed.
topo_plot
# This example may take a few seconds to render.
# Run only if you want to generate the full animation.
# Prepare a data structure:
s1e05 <- epochdata |> dplyr::filter(subject == 1 & epoch == 5 & time %in% c(10:20))
# Plot animation
# t0 = 10 indicates the time point of stimulus in epochdata,
# t_lim is the whole range of epochdata, we animate only a short period
animate_topo(s1e05, amplitude = "signal", t_lim = c(1,50), t0 = 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.