boxplot_rt: Plot interactive boxplots of response times

View source: R/boxplots.R

boxplot_rtR Documentation

Plot interactive boxplots of response times

Description

Function for plotting interactive boxplots of response time in individual epochs for selected subjects. The interactive plotly output enables to easily determine the epoch number from which outliers come and also allows to easily edit the image layout.

Usage

boxplot_rt(data, subject = NULL)

Arguments

data

A data frame or a database table with response times dataset. Required columns: subject, epoch, RT (value of response time in ms).

subject

A vector with IDs of subjects to plot. If missing, boxplots are drawn for all available subjects in data.

Value

A plotly object with boxplots of response times.

Examples

# Display interactive boxplots for both example subjects
boxplot_rt(rtdata)

diegr documentation built on Nov. 5, 2025, 5:25 p.m.