| boxplot_rt | R Documentation |
Function for plotting interactive boxplots of response time in individual epochs for selected subjects. The interactive plotly output enables to easily determine the epoch number from which outliers come and also allows to easily edit the image layout.
boxplot_rt(data, subject = NULL)
data |
A data frame or a database table with response times dataset. Required columns: subject, epoch, RT (value of response time in ms). |
subject |
A vector with IDs of subjects to plot. If missing, boxplots are drawn for all available subjects in |
A plotly object with boxplots of response times.
# Display interactive boxplots for both example subjects
boxplot_rt(rtdata)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.